@@ -1,14 +1,15 @@
-<?
+#!/usr/bin/php
+<?php
 
  mysql_connect("localhost","root","LetsTry08") or die ('nix connect');
  mysql_select_db("20000euro");
 
- $sql = "select distinct(email) from email_log;";
+ $sql = "select id, email from email_log;";
 
  $ergebnis = mysql_query($sql) or die('error: ' . $sql);
- $fhandle = fopen ("./_export_v2WMeTW3rY/leads.txt", "w");
+ $fhandle = fopen ("./exportdirectoryemails/leads.txt", "w");
  while($row = mysql_fetch_row($ergebnis)){
-  $line = $row[0] . "\n";
+  $line = $row[0] . "," . $row[1] . "\n";
   fwrite ($fhandle, $line);
  }
 
